####################################
#        GG_BUYLEVEL       
#                                 
#   Ported By TP.Predator, XE_ManUp, & {cDS} Artsemis
#      http://pred.yardimage.co.uk
#      http://www.twistedplay.co.uk
#         
####################################

# Main imports
import es
import playerlib

# GunGame imports
import gungamelib

# General Addon information
info = es.AddonInfo()
info.name        = "GunGame BuyLevel"
info.version     = "v1.0.0"
info.author      = "TP.Predator, XE_ManUp, & {cDS} Artsemis"
info.url         = "http://www.eventscripts.com"
info.description = "Buylevel command in Python for use with GGP"

playersCash = {}

def load():
    # Get BuyLevel Config
    gungamelib.getConfig('custom_addon_configs/gg_buylevel.cfg')

    # Check if saycommand exists, if not, create it
    if not es.exists('saycommand', gungamelib.getVariableValue('buy_cmd')):
        es.regsaycmd(gungamelib.getVariableValue('buy_cmd'), 'gungame/custom_addons/gg_buylevel/buylevel', 'Buy a GunGame Level')   

    # Register as GunGame Addon
    gg_buylevel = gungamelib.registerAddon('gg_buylevel')
    gg_buylevel.setDisplayName('GG Buy Level')
    gg_buylevel.loadTranslationFile()
   
    # Just incase we load the script in the middle of a map, initialize the players to $0
    for userid in es.getUseridList():
        if not str(userid) in playersCash:
            updateCash(str(userid), 0)

def unload():
    # Unassign the SayCommand
    es.unregsaycmd(gungamelib.getVariableValue('buy_cmd'))

    # Unregister GunGame Addon
    gungamelib.unregisterAddon('gg_buylevel')

def player_death(ev):
    # Get the player object
    pPlayer = playerlib.getPlayer(ev['attacker'])

    # Skip if in warmup
    if gungamelib.getGlobal('isWarmup'):
        es.dbgmsg(0, 'GGWarmup is currently active')
        return

    # Skip if killed by world
    if ev['attacker'] == '0':
        es.dbgmsg(0, 'Player killed by World')
        return

    # Skip if they killed themselves
    if ev['attacker'] == ev['userid']:
        es.dbgmsg(0, 'Player killed himself')
        return
   
    # Initialize the amount to modify funds by
    fundModifier = 0
   
    # Refund the losses if they killed a teammate
    if ev['es_userteam'] == ev['es_attackerteam']:
        fundModifier += 2700
       
    # Reduce cash by 300 due to amount from the game gives for a kill
    fundModifier -= 300
   
    # Calculate the new funds for the player and apply it
    newCashValue = int(pPlayer.get('cash')) + gungamelib.getVariableValue('buy_kill_reward') + fundModifier
    updateCash(ev['attacker'], newCashValue)

def gg_levelup(ev):
    # Reward player for leveling?
    if not gungamelib.getVariableValue('buy_level_reward') > 1:
        es.dbgmsg(0, 'Giving Money for Levelup Disabled')
        return

    if gungamelib.getGlobal('isWarmup'):
    # Skip if in warmup
        es.dbgmsg(0, 'GGWarmup is currently active')
        return

    # Checks passed, now to handle the player
    pPlayer = playerlib.getPlayer(ev['attacker'])

    # Add the cash defined in the config
    newCashValue = int(pPlayer.get('cash')) + gungamelib.getVariableValue('buy_level_reward')
    updateCash(ev['attacker'], newCashValue)

def player_activate(ev):
    # If this is a bot we don't need to handle them
    if es.isbot(ev['userid']):
        return

    # Set players starting cash to $0
    updateCash(ev['userid'], 0)
   
    # check if buy_announce is enabled
    if gungamelib.getVariableValue('buy_announce') != 1:
        es.dbgmsg(0, 'buy_announce is disabled, no message sent')
        return
       
    # Inform the player on how to use this addon
    gungamelib.msg('gg_buylevel',ev['userid'], 'PlayerJoinMsg', {'var1':gungamelib.getVariableValue('buy_cmd'), 'var2':gungamelib.getVariableValue('buy_level_cost')})
   
def player_spawn(ev):
    if not playersCash.has_key(ev['userid']):
        updateCash(ev['userid'], 0)
    playerlib.getPlayer(ev['userid']).set("cash", playersCash[ev['userid']])
   
def es_map_start(ev):
    playersCash.clear()

def gg_win(ev):
    playersCash.clear()

def buylevel():
    # Get Players UserId
    userid = es.getcmduserid()

    # Setup Playerlib for specific player
    pPlayer = playerlib.getPlayer(userid)

    # Setup GunGameLib for specific player
    gPlayer = gungamelib.getPlayer(userid)

    # Get Players cash for checking later
    pCash = pPlayer.get('cash')

    # Skip if in Warmup
    if gungamelib.getGlobal('isWarmup'):
        gungamelib.msg('gg_buylevel',userid, 'InWarmup')
        return
       
    # Skip if game is over
    if gungamelib.getGlobal('gameOver'):
        gungamelib.msg('gg_buylevel', userid, 'GameOver')
        return

    # Check if level can be skipped
    if gPlayer.getWeapon() in gungamelib.getVariableValue('buy_no_skip'):
        gungamelib.msg('gg_buylevel', userid, 'NoSkipLevel')
        return

    # Check they can afford a level
    if not pCash >= gungamelib.getVariableValue('buy_level_cost'):
        gungamelib.msg('gg_buylevel', userid, 'NotEnoughCash', {'cost': '$' + str(gungamelib.getVariableValue('buy_level_cost'))})
        return

    # Set there level
    gPlayer['level'] += 1
    gungamelib.playSound(userid, 'levelup')
       
    # Don't strip and give weapons if the player is dead
    if not gungamelib.isDead(userid):
        # Strip the player of there weapons
        gPlayer.stripPlayer()

        # Give them there weapon
        gPlayer.giveWeapon()

    # Take the players cash
    newCashValue = int(pPlayer.get('cash')) - gungamelib.getVariableValue('buy_level_cost')
    updateCash(str(userid), newCashValue)
   
def updateCash(userid, value):
    pPlayer = playerlib.getPlayer(userid)
   
    # Make sure the cash is within the allowed range
    if value < 0:
        value = 0
    elif value > 16000:
        value = 16000
   
    # Update both the display value and our private dict
    pPlayer.set('cash', value)
    playersCash[userid] = value